==> 0.13.10.tar.gz: tonyslist/templates/markdown/terms-of-service.md <==
# Terms of Use

Last Updated: 2023-08-20

## Welcome to OrcasHub!

We (OrcasHub) hope you find our website useful and helpful for your Orcas Island
endeavors. By accessing or otherwise interacting with our servers, services,
websites, or any associated content/postings, you agree to these Terms of Use
("TOU") (2023-04-12). You acknowledge and agree OrcasHub is a private site owned
and operated by [Tony Grosinger]. If you are accessing or using OrcasHub on
behalf of a business, you represent and warrant to OrcasHub that you have
authority to accept the TOU on behalf of that business and that that business
agrees to the TOU. If you do not agree to the TOU, you are not authorized to use
OrcasHub. We may modify the TOU at any time in our sole discretion. You are
responsible for periodically checking for changes and are bound by them if you
continue to use OrcasHub. Our [privacy policy](/privacy-policy) and all other
policies, site rules, and agreements referenced below or on OrcasHub, are fully
incorporated into this TOU, and you agree to them as well.

## Community Expectations

OrcasHub is a welcoming space for all full-time or part-time residents of San
Juan County. We as members, contributors, and leaders pledge to make
participation in our community a harassment-free experience for everyone,
regardless of age, body size, visible or invisible disability, ethnicity, sex
characteristics, gender identity and expression, level of experience, education,
socio-economic status, nationality, personal appearance, race, caste, color,
religion, or sexual identity and orientation. We pledge to act and interact in
ways that contribute to an open, welcoming, diverse, inclusive, and healthy
community. When using this site, please be mindful that any content you post is
respectful, charitable, and considerate towards all people. This is not the
place to have political or controversial discussions or debates.

## Additional Terms

By using OrcasHub, you acknowledge and agree that you:

- will adhere to the community expectations and guidelines outlined above and
  below.
- are a full or part-time resident of San Juan County.
- are using an account registered under your own name.
- are registering with legitimate personal contact information.
- will not impersonate, or otherwise misrepresent affiliation, connection or
  association with, any person or entity.
- will not post content which is defamatory, derogatory, offensive, harassing,
  disrespectful, or exclusionary towards any people.
- will not use the website to promote your own or other business or commercial
  interests. Exceptions may be made by the site owner for non-profit organizations
  on a case-by-case basis.
- will post only items that contain truthful information and verifiable facts
  and will refrain from posting "alternative facts", conspiracy theories, false
  statements, hearsay or rumors.
- will not post content to which you do not have the rights to publish or
  distribute.
- are granting this site a perpetual, irrevocable, unlimited, worldwide, fully
  paid/sublicensable license to use, copy, display, distribute, and make
  derivative works from content you post.
- will not copy/collect OrcasHub content via robots, spiders, scripts, scrapers,
  crawlers, or any automated or manual equivalent (e.g., by hand).

When using the OrcasHub Classifieds section of this website, you acknowledge and
agree that you:

- will only post items for sale which you rightfully own.
- will not post items or activities which violate local, county, state, or
  federal law or regulations.
- will accurately represent any items posted and not aim to mislead potential
  buyers.
- will not post items or content on behalf of others outside of your household.
- will mark items as sold or delete posts promptly when the item is no longer
  available.

When using the OrcasHub Housing section of this website, you acknowledge and
agree that you:

- will accurately represent yourself and the listing and not aim to mislead
  potential buyers.
- will not post on behalf of others outside of your household.
- will be responsible for checking references of potential land-hosts or tenants.

When using the OrcasHub Mailing Lists section of this website, you acknowledge and
agree that you:

- will not violate local, county, state, or federal law or regulations.
- understand that there is no expectation of privacy for any content you upload,
  submit, post, email, or exchange through any other means.
- acknowledge that all posts will be viewed by moderators of the site, even if
  the mailing list is private.
- are soley responsible for any content you upload, submit, post, email, or
  exchange through any other means.

Additionally, by using OrcasHub, you acknowledge and agree that:

- you will not harass or bully other users or moderators of this website.
- misleading, unsolicited, and/or unlawful postings/communications/accounts are
  prohibited, as is buying or selling accounts.
- any content may be removed from the site at the discretion of the content
  moderators.
- any content may be moved, merged, or modified at the discretion of the content
  moderators.
- any user may be removed from the site at the discretion of content moderators.
  Users removed are not permitted to create a new account.
- all users of the site are visitors to a volunteer-run service that provides no
  guarantees to any users; OrcasHub provide its service on an "AS IS" and "AS
  AVAILABLE" basis and any risk of using OrcasHub is assumed by you.
- any donations made by a user to the site are (a) non-refundable, (b) do not
  serve as a guarantee service, and (c) will not result in any preferential
  treatment of the user by the site owner or moderators.
- OrcasHub makes no promises, warranties, or representations as to OrcasHub,
  including its completeness, accuracy, availability, timeliness, propriety,
  security or reliability. OrcasHub disclaims all warranties, express or implied,
  including as to accuracy, merchantability, fitness for a particular purpose, and
  non-infringement, and all warranties arising from course of dealing, usage, or
  trade practice.
- OrcasHub disclaims any liability or responsibility for acts, omissions, or
  conduct of you or any party in connection with OrcasHub. OrcasHub is NOT liable
  for any direct, indirect, consequential, incidental, special, punitive, or other
  losses, including lost profits, revenues, data, goodwill, etc., arising from or
  related to OrcasHub.
- any claim, cause of action, demand, or dispute arising from or related to
  OrcasHub will be governed by the internal laws of Washington State, without
  regard to conflict of law provisions, except to the extent governed by US
  federal law. You agree to (1) submit to the personal jurisdiction of courts in
  Washington State; (2) indemnify and hold OrcasHub harmless from any claims,
  losses, liability, or expenses (including attorneys' fees) that arise from a
  third party and relate to your use of OrcasHub; and (3) be liable and
  responsible for any claims we may have against your officers, directors,
  employees, agents, affiliates, or any other party, directly or indirectly, paid,
  directed or controlled by you, or acting for your benefit.

==> 0.14.1.tar.gz: tonyslist/templates/markdown/terms-of-service.md <==
# Terms of Use

Last Updated: 2023-08-20

## Welcome to OrcasHub!

We (OrcasHub) hope you find our website useful and helpful for your Orcas Island
endeavors. By accessing or otherwise interacting with our servers, services,
websites, or any associated content/postings, you agree to these Terms of Use
("TOU") (2023-04-12). You acknowledge and agree OrcasHub is a private site owned
and operated by [Tony Grosinger]. If you are accessing or using OrcasHub on
behalf of a business, you represent and warrant to OrcasHub that you have
authority to accept the TOU on behalf of that business and that that business
agrees to the TOU. If you do not agree to the TOU, you are not authorized to use
OrcasHub. We may modify the TOU at any time in our sole discretion. You are
responsible for periodically checking for changes and are bound by them if you
continue to use OrcasHub. Our [privacy policy](/privacy-policy) and all other
policies, site rules, and agreements referenced below or on OrcasHub, are fully
incorporated into this TOU, and you agree to them as well.

## Community Expectations

OrcasHub is a welcoming space for all full-time or part-time residents of San
Juan County. We as members, contributors, and leaders pledge to make
participation in our community a harassment-free experience for everyone,
regardless of age, body size, visible or invisible disability, ethnicity, sex
characteristics, gender identity and expression, level of experience, education,
socio-economic status, nationality, personal appearance, race, caste, color,
religion, or sexual identity and orientation. We pledge to act and interact in
ways that contribute to an open, welcoming, diverse, inclusive, and healthy
community. When using this site, please be mindful that any content you post is
respectful, charitable, and considerate towards all people. This is not the
place to have political or controversial discussions or debates.

## Additional Terms

By using OrcasHub, you acknowledge and agree that you:

- will adhere to the community expectations and guidelines outlined above and
  below.
- are a full or part-time resident of San Juan County.
- are using an account registered under your own name.
- are registering with legitimate personal contact information.
- will not impersonate, or otherwise misrepresent affiliation, connection or
  association with, any person or entity.
- will not post content which is defamatory, derogatory, offensive, harassing,
  disrespectful, or exclusionary towards any people.
- will not use the website to promote your own or other business or commercial
  interests. Exceptions may be made by the site owner for non-profit organizations
  on a case-by-case basis.
- will post only items that contain truthful information and verifiable facts
  and will refrain from posting "alternative facts", conspiracy theories, false
  statements, hearsay or rumors.
- will not post content to which you do not have the rights to publish or
  distribute.
- are granting this site a perpetual, irrevocable, unlimited, worldwide, fully
  paid/sublicensable license to use, copy, display, distribute, and make
  derivative works from content you post.
- will not copy/collect OrcasHub content via robots, spiders, scripts, scrapers,
  crawlers, or any automated or manual equivalent (e.g., by hand).

When using the OrcasHub Classifieds section of this website, you acknowledge and
agree that you:

- will only post items for sale which you rightfully own.
- will not post items or activities which violate local, county, state, or
  federal law or regulations.
- will accurately represent any items posted and not aim to mislead potential
  buyers.
- will not post items or content on behalf of others outside of your household.
- will mark items as sold or delete posts promptly when the item is no longer
  available.

When using the OrcasHub Housing section of this website, you acknowledge and
agree that you:

- will accurately represent yourself and the listing and not aim to mislead
  potential buyers.
- will not post on behalf of others outside of your household.
- will be responsible for checking references of potential land-hosts or tenants.

When using the OrcasHub Groups section of this website, you acknowledge and
agree that you:

- will not violate local, county, state, or federal law or regulations.
- understand that there is no expectation of privacy for any content you upload,
  submit, post, email, or exchange through any other means.
- acknowledge that all posts will be viewed by moderators of the site, even if
  the mailing list is private.
- are soley responsible for any content you upload, submit, post, email, or
  exchange through any other means.

Additionally, by using OrcasHub, you acknowledge and agree that:

- you will not harass or bully other users or moderators of this website.
- misleading, unsolicited, and/or unlawful postings/communications/accounts are
  prohibited, as is buying or selling accounts.
- any content may be removed from the site at the discretion of the content
  moderators.
- any content may be moved, merged, or modified at the discretion of the content
  moderators.
- any user may be removed from the site at the discretion of content moderators.
  Users removed are not permitted to create a new account.
- all users of the site are visitors to a volunteer-run service that provides no
  guarantees to any users; OrcasHub provide its service on an "AS IS" and "AS
  AVAILABLE" basis and any risk of using OrcasHub is assumed by you.
- any donations made by a user to the site are (a) non-refundable, (b) do not
  serve as a guarantee service, and (c) will not result in any preferential
  treatment of the user by the site owner or moderators.
- OrcasHub makes no promises, warranties, or representations as to OrcasHub,
  including its completeness, accuracy, availability, timeliness, propriety,
  security or reliability. OrcasHub disclaims all warranties, express or implied,
  including as to accuracy, merchantability, fitness for a particular purpose, and
  non-infringement, and all warranties arising from course of dealing, usage, or
  trade practice.
- OrcasHub disclaims any liability or responsibility for acts, omissions, or
  conduct of you or any party in connection with OrcasHub. OrcasHub is NOT liable
  for any direct, indirect, consequential, incidental, special, punitive, or other
  losses, including lost profits, revenues, data, goodwill, etc., arising from or
  related to OrcasHub.
- any claim, cause of action, demand, or dispute arising from or related to
  OrcasHub will be governed by the internal laws of Washington State, without
  regard to conflict of law provisions, except to the extent governed by US
  federal law. You agree to (1) submit to the personal jurisdiction of courts in
  Washington State; (2) indemnify and hold OrcasHub harmless from any claims,
  losses, liability, or expenses (including attorneys' fees) that arise from a
  third party and relate to your use of OrcasHub; and (3) be liable and
  responsible for any claims we may have against your officers, directors,
  employees, agents, affiliates, or any other party, directly or indirectly, paid,
  directed or controlled by you, or acting for your benefit.
